@@ -7,7 +7,7 @@ test_that("generate_documentation correctly produces a results needed for the do
   #find path to apps
   packagename = 'DSAIRM'
   appdir = system.file("appinformation", package = packagename) #find path to apps
-  appName = "virusandtx"
+  appName = "basicbacteria"
   at = read.table(file = paste0(appdir,"/apptable.tsv"), sep = '\t', header = TRUE)
   appsettings <<- as.list(at[which(at$appid == appName),])
   #file name for documentation
@@ -15,5 +15,5 @@ test_that("generate_documentation correctly produces a results needed for the do
   docs = generate_documentation(currentdocfilename)
   #these elements of the tag list needs to contain the indicated words
   expect_true(grepl("Overview",docs[[1]][[2]]$title))
-  expect_true(grepl("drug",docs[[1]][[3]]))
+  #expect_true(grepl("drug",docs[[1]][[3]]))
 })
